from pydantic import BaseModel
from typing import Optional, List
from datetime import datetime
from .orderitem import OrderItemRead

class OrderBase(BaseModel):
    shop_id: int
    total_price: float
    status: Optional[str] = "pending"

class OrderCreate(OrderBase):
    pass

class OrderRead(OrderBase):
    id: int
    user_id: int
    created_at: datetime

    class Config:
        orm_mode = True

class OrderUpdate(BaseModel):
    shop_id: Optional[int] = None
    total_price: Optional[float] = None
    status: Optional[str] = None

class OrderList(BaseModel):
    orders: List[OrderRead]

class OrderWithItems(OrderRead):
    order_items: List[OrderItemRead] = []
