import customtkinter as ctk
import requests
from tkinter import messagebox


def product_frame(parent, switch_func, API_URL, token):
    frame = ctk.CTkFrame(parent)

    ctk.CTkLabel(frame, text="Product Management", font=("Helvetica", 18, "bold")).pack(
        pady=10
    )

    ctk.CTkLabel(frame, text="Product Name:").pack(pady=5)
    entry_name = ctk.CTkEntry(frame)
    entry_name.pack(pady=5)

    ctk.CTkLabel(frame, text="Price:").pack(pady=5)
    entry_price = ctk.CTkEntry(frame)
    entry_price.pack(pady=5)

    ctk.CTkLabel(frame, text="Stock:").pack(pady=5)
    entry_stock = ctk.CTkEntry(frame)
    entry_stock.pack(pady=5)

    def create_product():
        name = entry_name.get().strip()
        price = entry_price.get().strip()
        stock = entry_stock.get().strip()

        if not name or not price or not stock:
            messagebox.showwarning("Input Error", "All fields are required!")
            return

        try:
            price = float(price)
            stock = int(stock)
        except ValueError:
            messagebox.showwarning(
                "Input Error", "Price must be a number and Stock must be an integer."
            )
            return

        headers = {"Authorization": f"Bearer {token}"}
        data = {"name": name, "price": price, "stock": stock}

        try:
            response = requests.post(f"{API_URL}/products", json=data, headers=headers)

            if response.status_code == 200:
                messagebox.showinfo(
                    "Success", f"Product '{name}' created successfully!"
                )
                entry_name.delete(0, "end")
                entry_price.delete(0, "end")
                entry_stock.delete(0, "end")
            else:
                error_message = response.json().get(
                    "detail", "Failed to create product"
                )
                messagebox.showerror("Error", error_message)
        except requests.exceptions.RequestException as e:
            messagebox.showerror("Error", f"Failed to connect to server: {e}")

    ctk.CTkButton(frame, text="Create Product", command=create_product).pack(pady=15)
    ctk.CTkButton(frame, text="Back", command=lambda: switch_func("view_shop")).pack(
        pady=5
    )

    return frame
